@@ -457,6 +457,8 @@ clutter_stage_cogl_redraw (ClutterStageWindow *stage_window)
       may_use_clipped_redraw = TRUE;
       clip_region = &stage_cogl->bounding_redraw_clip;
     }
+  else
+    clip_region = NULL;
 
   if (may_use_clipped_redraw &&
       G_LIKELY (!(clutter_paint_debug_flags & CLUTTER_DEBUG_DISABLE_CLIPPED_REDRAWS)))
@@ -559,8 +561,7 @@ clutter_stage_cogl_redraw (ClutterStageWindow *stage_window)
       if (G_UNLIKELY (clutter_paint_debug_flags & CLUTTER_DEBUG_DISABLE_CLIPPED_REDRAWS) &&
           may_use_clipped_redraw)
         {
-          _clutter_stage_do_paint (CLUTTER_STAGE (wrapper),
-                                   clip_region);
+          _clutter_stage_do_paint (CLUTTER_STAGE (wrapper), clip_region);
         }
       else
         _clutter_stage_do_paint (CLUTTER_STAGE (wrapper), NULL);
