@@ -28,6 +28,9 @@
 #endif
 
 #include <cogl/cogl.h>
+
+#define GDK_DISABLE_DEPRECATION_WARNINGS
+
 #include <gdk/gdk.h>
 #ifdef GDK_WINDOWING_X11
 #include <gdk/gdkx.h>
@@ -225,7 +228,7 @@ clutter_stage_gdk_realize (ClutterStageWindow *stage_window)
           if (!cursor_visible)
             {
               if (stage_gdk->blank_cursor == NULL)
-                stage_gdk->blank_cursor = gdk_cursor_new (GDK_BLANK_CURSOR);
+                stage_gdk->blank_cursor = gdk_cursor_new_for_display (backend_gdk->display, GDK_BLANK_CURSOR);
 
               attributes.cursor = stage_gdk->blank_cursor;
             }
@@ -344,7 +347,11 @@ clutter_stage_gdk_set_cursor_visible (ClutterStageWindow *stage_window,
   else
     {
       if (stage_gdk->blank_cursor == NULL)
-	stage_gdk->blank_cursor = gdk_cursor_new (GDK_BLANK_CURSOR);
+        {
+          GdkDisplay *display = clutter_gdk_get_default_display ();
+
+	  stage_gdk->blank_cursor = gdk_cursor_new_for_display (display, GDK_BLANK_CURSOR);
+        }
 
       gdk_window_set_cursor (stage_gdk->window, stage_gdk->blank_cursor);
     }
@@ -426,6 +433,17 @@ clutter_stage_gdk_can_clip_redraws (ClutterStageWindow *stage_window)
   return TRUE;
 }
 
+static int
+clutter_stage_gdk_get_scale_factor (ClutterStageWindow *stage_window)
+{
+  ClutterStageGdk *stage_gdk = CLUTTER_STAGE_GDK (stage_window);
+
+  if (stage_gdk->window == NULL)
+    return 1;
+
+  return gdk_window_get_scale_factor (stage_gdk->window);
+}
+
 static void
 clutter_stage_gdk_dispose (GObject *gobject)
 {
@@ -482,6 +500,7 @@ clutter_stage_window_iface_init (ClutterStageWindowIface *iface)
   iface->realize = clutter_stage_gdk_realize;
   iface->unrealize = clutter_stage_gdk_unrealize;
   iface->can_clip_redraws = clutter_stage_gdk_can_clip_redraws;
+  iface->get_scale_factor = clutter_stage_gdk_get_scale_factor;
 }
 
 /**
